==> zego_zimkit-1.15.0.tar.gz: lib/src/pages/message_list_page.dart <==
import 'dart:async';

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:zego_zim/zego_zim.dart';
import 'package:zego_zimkit/src/components/components.dart';
import 'package:zego_zimkit/src/services/services.dart';

class ZIMKitMessageListPage extends StatelessWidget {
  const ZIMKitMessageListPage({
    Key? key,
    required this.conversationID,
    this.conversationType = ZIMConversationType.peer,
    this.appBarBuilder,
    this.appBarActions,
    this.messageInputActions,
    this.onMessageSent,
    this.preMessageSending,
    this.inputDecoration,
    this.showPickFileButton = true,
    this.showPickMediaButton = true,
    this.editingController,
    this.messageListScrollController,
    this.onMessageItemPressed,
    this.onMessageItemLongPress,
    this.messageItemBuilder,
    this.messageListErrorBuilder,
    this.messageListLoadingBuilder,
    this.messageListBackgroundBuilder,
    this.theme,
    this.onMediaFilesPicked,
    this.sendButtonWidget,
    this.pickMediaButtonWidget,
    this.pickFileButtonWidget,
    this.inputFocusNode,
    this.inputBackgroundDecoration,
    this.messageInputContainerPadding,
    this.messageInputContainerDecoration,
    this.messageInputKeyboardType,
    this.messageInputMaxLines,
    this.messageInputMinLines,
    this.messageInputTextInputAction,
    this.messageInputTextCapitalization,
  }) : super(key: key);

  /// this page's conversationID
  final String conversationID;

  /// this page's conversationType
  final ZIMConversationType conversationType;

  /// if you just want add some actions to the appBar, use [appBarActions].
  ///
  /// use it like this:
  /// appBarActions:[
  ///   IconButton(icon: const Icon(Icons.local_phone), onPressed: () {}),
  ///   IconButton(icon: const Icon(Icons.videocam), onPressed: () {}),
  /// ],
  final List<Widget>? appBarActions;

  // if you want customize the appBar, use appBarBuilder return your custom appBar
  // if you don't want use appBar, return null
  final AppBar? Function(
    BuildContext context,
    AppBar defaultAppBar,
  )? appBarBuilder;

  /// To add your own action, use the [messageInputActions] parameter like this:
  ///
  /// use [messageInputActions] like this to add your custom actions:
  ///
  /// actions: [
  ///   ZIMKitMessageInputAction.left(
  ///     IconButton(icon: Icon(Icons.mic), onPressed: () {})
  ///   ),
  ///   ZIMKitMessageInputAction.leftInside(
  ///     IconButton(icon: Icon(Icons.sentiment_satisfied_alt_outlined), onPressed: () {})
  ///   ),
  ///   ZIMKitMessageInputAction.rightInside(
  ///     IconButton(icon: Icon(Icons.cabin), onPressed: () {})
  ///   ),
  ///   ZIMKitMessageInputAction.right(
  ///     IconButton(icon: Icon(Icons.sd), onPressed: () {})
  ///   ),
  /// ],
  final List<ZIMKitMessageInputAction>? messageInputActions;

  /// Called when a message is sent.
  final void Function(ZIMKitMessage)? onMessageSent;

  /// Called before a message is sent.
  final FutureOr<ZIMKitMessage> Function(ZIMKitMessage)? preMessageSending;

  /// By default, [ZIMKitMessageInput] will show a button to pick file.
  /// If you don't want to show this button, set [showPickFileButton] to false.
  final bool showPickFileButton;

  /// By default, [ZIMKitMessageInput] will show a button to pick media.
  /// If you don't want to show this button, set [showPickMediaButton] to false.
  final bool showPickMediaButton;

  /// The TextField's decoration.
  final InputDecoration? inputDecoration;

  /// The [TextEditingController] to use.
  /// if not provided, a default one will be created.
  final TextEditingController? editingController;

  /// The [ScrollController] to use.
  /// if not provided, a default one will be created.
  final ScrollController? messageListScrollController;

  /// The default config is
  /// ```dart
  /// const EdgeInsets.symmetric(horizontal: 20, vertical: 10)
  /// ```
  final EdgeInsetsGeometry? messageInputContainerPadding;

  /// The default config is
  /// ```dart
  /// BoxDecoration(
  ///   color: Theme.of(context).scaffoldBackgroundColor,
  ///   boxShadow: [
  ///     BoxShadow(
  ///       offset: const Offset(0, 4),
  ///       blurRadius: 32,
  ///       color: Theme.of(context).primaryColor.withOpacity(0.15),
  ///     ),
  ///   ],
  /// )
  /// ```
  final Decoration? messageInputContainerDecoration;

  /// default is TextInputType.multiline
  final TextInputType? messageInputKeyboardType;

  // default is 3
  final int? messageInputMaxLines;

  // default is 1
  final int? messageInputMinLines;

  // default is TextInputAction.newline
  final TextInputAction? messageInputTextInputAction;

  // default is TextCapitalization.sentences
  final TextCapitalization? messageInputTextCapitalization;

  final void Function(
    BuildContext context,
    ZIMKitMessage message,
    Function defaultAction,
  )? onMessageItemPressed;
  final void Function(
    BuildContext context,
    LongPressStartDetails details,
    ZIMKitMessage message,
    Function defaultAction,
  )? onMessageItemLongPress;
  final Widget Function(
    BuildContext context,
    ZIMKitMessage message,
    Widget defaultWidget,
  )? messageItemBuilder;
  final Widget Function(
    BuildContext context,
    Widget defaultWidget,
  )? messageListErrorBuilder;
  final Widget Function(
    BuildContext context,
    Widget defaultWidget,
  )? messageListLoadingBuilder;
  final Widget Function(
    BuildContext context,
    Widget defaultWidget,
  )? messageListBackgroundBuilder;

  final void Function(BuildContext context, List<PlatformFile> files,
      Function defaultAction)? onMediaFilesPicked;

  // theme
  final ThemeData? theme;

  final Widget? sendButtonWidget;

  final Widget? pickMediaButtonWidget;

  final Widget? pickFileButtonWidget;

  final FocusNode? inputFocusNode;

  final BoxDecoration? inputBackgroundDecoration;

  @override
  Widget build(BuildContext context) {
    return Theme(
      data: theme ?? Theme.of(context),
      child: Scaffold(
        appBar: appBarBuilder?.call(context, buildAppBar(context)) ??
            buildAppBar(context),
        body: Column(
          children: [
            ZIMKitMessageListView(
              key: ValueKey(
                'ZIMKitMessageListView:${Object.hash(
                  conversationID,
                  conversationType,
                )}',
              ),
              conversationID: conversationID,
              conversationType: conversationType,
              onPressed: onMessageItemPressed,
              itemBuilder: messageItemBuilder,
              onLongPress: onMessageItemLongPress,
              loadingBuilder: messageListLoadingBuilder,
              errorBuilder: messageListErrorBuilder,
              scrollController: messageListScrollController,
              theme: theme,
              backgroundBuilder: messageListBackgroundBuilder,
            ),
            ZIMKitMessageInput(
              key: ValueKey(
                'ZIMKitMessageInput:${Object.hash(
                  conversationID,
                  conversationType,
                )}',
              ),
              conversationID: conversationID,
              conversationType: conversationType,
              actions: messageInputActions,
              onMessageSent: onMessageSent,
              preMessageSending: preMessageSending,
              inputDecoration: inputDecoration,
              showPickFileButton: showPickFileButton,
              showPickMediaButton: showPickMediaButton,
              editingController: editingController,
              theme: theme,
              onMediaFilesPicked: onMediaFilesPicked,
              sendButtonWidget: sendButtonWidget,
              pickMediaButtonWidget: pickMediaButtonWidget,
              pickFileButtonWidget: pickFileButtonWidget,
              inputFocusNode: inputFocusNode,
              inputBackgroundDecoration: inputBackgroundDecoration,
              containerPadding: messageInputContainerPadding,
              containerDecoration: messageInputContainerDecoration,
              keyboardType: messageInputKeyboardType,
              maxLines: messageInputMaxLines,
              minLines: messageInputMinLines,
              textInputAction: messageInputTextInputAction,
              textCapitalization: messageInputTextCapitalization,
            ),
          ],
        ),
      ),
    );
  }

  AppBar buildAppBar(BuildContext context) {
    return AppBar(
      title: ValueListenableBuilder<ZIMKitConversation>(
        valueListenable: ZIMKit().getConversation(
          conversationID,
          conversationType,
        ),
        builder: (context, conversation, child) {
          const avatarNameFontSize = 16.0;
          return Row(
            children: [
              ClipRRect(
                borderRadius: const BorderRadius.all(Radius.circular(40)),
                child: conversation.icon,
              ),
              child!,
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(
                    conversation.name,
                    style: const TextStyle(
                      fontSize: avatarNameFontSize,
                    ),
                    overflow: TextOverflow.clip,
                  ),
                  // Text(conversation.id,
                  //     style: const TextStyle(fontSize: 12),
                  //     overflow: TextOverflow.clip)
                ],
              )
            ],
          );
        },
        child: const SizedBox(width: 20 * 0.75),
      ),
      actions: appBarActions,
    );
  }
}

==> zego_zimkit-1.17.0.tar.gz: lib/src/pages/message_list_page.dart <==
import 'dart:async';

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:zego_zim/zego_zim.dart';
import 'package:zego_zimkit/src/components/components.dart';
import 'package:zego_zimkit/src/services/services.dart';

class ZIMKitMessageListPage extends StatelessWidget {
  const ZIMKitMessageListPage({
    Key? key,
    required this.conversationID,
    this.conversationType = ZIMConversationType.peer,
    this.appBarBuilder,
    this.appBarActions,
    this.messageInputActions,
    this.onMessageSent,
    this.preMessageSending,
    this.inputDecoration,
    this.showPickFileButton = true,
    this.showPickMediaButton = true,
    this.editingController,
    this.messageListScrollController,
    this.onMessageItemPressed,
    this.onMessageItemLongPress,
    this.messageItemBuilder,
    this.messageContentBuilder,
    this.messageListErrorBuilder,
    this.messageListLoadingBuilder,
    this.messageListBackgroundBuilder,
    this.theme,
    this.onMediaFilesPicked,
    this.sendButtonWidget,
    this.pickMediaButtonWidget,
    this.pickFileButtonWidget,
    this.inputFocusNode,
    this.inputBackgroundDecoration,
    this.messageInputContainerPadding,
    this.messageInputContainerDecoration,
    this.messageInputKeyboardType,
    this.messageInputMaxLines,
    this.messageInputMinLines,
    this.messageInputTextInputAction,
    this.messageInputTextCapitalization,
  }) : super(key: key);

  /// this page's conversationID
  final String conversationID;

  /// this page's conversationType
  final ZIMConversationType conversationType;

  /// if you just want add some actions to the appBar, use [appBarActions].
  ///
  /// use it like this:
  /// appBarActions:[
  ///   IconButton(icon: const Icon(Icons.local_phone), onPressed: () {}),
  ///   IconButton(icon: const Icon(Icons.videocam), onPressed: () {}),
  /// ],
  final List<Widget>? appBarActions;

  // if you want customize the appBar, use appBarBuilder return your custom appBar
  // if you don't want use appBar, return null
  final AppBar? Function(BuildContext context, AppBar defaultAppBar)? appBarBuilder;

  /// To add your own action, use the [messageInputActions] parameter like this:
  ///
  /// use [messageInputActions] like this to add your custom actions:
  ///
  /// actions: [
  ///   ZIMKitMessageInputAction.left(
  ///     IconButton(icon: Icon(Icons.mic), onPressed: () {})
  ///   ),
  ///   ZIMKitMessageInputAction.leftInside(
  ///     IconButton(icon: Icon(Icons.sentiment_satisfied_alt_outlined), onPressed: () {})
  ///   ),
  ///   ZIMKitMessageInputAction.rightInside(
  ///     IconButton(icon: Icon(Icons.cabin), onPressed: () {})
  ///   ),
  ///   ZIMKitMessageInputAction.right(
  ///     IconButton(icon: Icon(Icons.sd), onPressed: () {})
  ///   ),
  /// ],
  final List<ZIMKitMessageInputAction>? messageInputActions;

  /// Called when a message is sent.
  final void Function(ZIMKitMessage)? onMessageSent;

  /// Called before a message is sent.
  final FutureOr<ZIMKitMessage> Function(ZIMKitMessage)? preMessageSending;

  /// By default, [ZIMKitMessageInput] will show a button to pick file.
  /// If you don't want to show this button, set [showPickFileButton] to false.
  final bool showPickFileButton;

  /// By default, [ZIMKitMessageInput] will show a button to pick media.
  /// If you don't want to show this button, set [showPickMediaButton] to false.
  final bool showPickMediaButton;

  /// The TextField's decoration.
  final InputDecoration? inputDecoration;

  /// The [TextEditingController] to use.
  /// if not provided, a default one will be created.
  final TextEditingController? editingController;

  /// The [ScrollController] to use.
  /// if not provided, a default one will be created.
  final ScrollController? messageListScrollController;

  /// The default config is
  /// ```dart
  /// const EdgeInsets.symmetric(horizontal: 20, vertical: 10)
  /// ```
  final EdgeInsetsGeometry? messageInputContainerPadding;

  /// The default config is
  /// ```dart
  /// BoxDecoration(
  ///   color: Theme.of(context).scaffoldBackgroundColor,
  ///   boxShadow: [
  ///     BoxShadow(
  ///       offset: const Offset(0, 4),
  ///       blurRadius: 32,
  ///       color: Theme.of(context).primaryColor.withOpacity(0.15),
  ///     ),
  ///   ],
  /// )
  /// ```
  final Decoration? messageInputContainerDecoration;

  /// default is TextInputType.multiline
  final TextInputType? messageInputKeyboardType;

  // default is 3
  final int? messageInputMaxLines;

  // default is 1
  final int? messageInputMinLines;

  // default is TextInputAction.newline
  final TextInputAction? messageInputTextInputAction;

  // default is TextCapitalization.sentences
  final TextCapitalization? messageInputTextCapitalization;

  final void Function(BuildContext context, ZIMKitMessage message, Function defaultAction)? onMessageItemPressed;
  final void Function(
          BuildContext context, LongPressStartDetails details, ZIMKitMessage message, Function defaultAction)?
      onMessageItemLongPress;
  final Widget Function(BuildContext context, ZIMKitMessage message, Widget defaultWidget)? messageItemBuilder;
  final Widget Function(BuildContext context, ZIMKitMessage message, Widget defaultWidget)? messageContentBuilder;
  final Widget Function(BuildContext context, Widget defaultWidget)? messageListErrorBuilder;
  final Widget Function(BuildContext context, Widget defaultWidget)? messageListLoadingBuilder;
  final Widget Function(BuildContext context, Widget defaultWidget)? messageListBackgroundBuilder;

  final void Function(BuildContext context, List<PlatformFile> files, Function defaultAction)? onMediaFilesPicked;

  // theme
  final ThemeData? theme;

  final Widget? sendButtonWidget;

  final Widget? pickMediaButtonWidget;

  final Widget? pickFileButtonWidget;

  final FocusNode? inputFocusNode;

  final BoxDecoration? inputBackgroundDecoration;

  @override
  Widget build(BuildContext context) {
    return Theme(
      data: theme ?? Theme.of(context),
      child: Scaffold(
        appBar: appBarBuilder?.call(context, buildAppBar(context)) ?? buildAppBar(context),
        body: Column(
          children: [
            ZIMKitMessageListView(
              key: ValueKey(
                'ZIMKitMessageListView:${Object.hash(
                  conversationID,
                  conversationType,
                )}',
              ),
              conversationID: conversationID,
              conversationType: conversationType,
              onPressed: onMessageItemPressed,
              itemBuilder: messageItemBuilder,
              messageContentBuilder: messageContentBuilder,
              onLongPress: onMessageItemLongPress,
              loadingBuilder: messageListLoadingBuilder,
              errorBuilder: messageListErrorBuilder,
              scrollController: messageListScrollController,
              theme: theme,
              backgroundBuilder: messageListBackgroundBuilder,
            ),
            ZIMKitMessageInput(
              key: ValueKey(
                'ZIMKitMessageInput:${Object.hash(
                  conversationID,
                  conversationType,
                )}',
              ),
              conversationID: conversationID,
              conversationType: conversationType,
              actions: messageInputActions,
              onMessageSent: onMessageSent,
              preMessageSending: preMessageSending,
              inputDecoration: inputDecoration,
              showPickFileButton: showPickFileButton,
              showPickMediaButton: showPickMediaButton,
              editingController: editingController,
              theme: theme,
              onMediaFilesPicked: onMediaFilesPicked,
              sendButtonWidget: sendButtonWidget,
              pickMediaButtonWidget: pickMediaButtonWidget,
              pickFileButtonWidget: pickFileButtonWidget,
              inputFocusNode: inputFocusNode,
              inputBackgroundDecoration: inputBackgroundDecoration,
              containerPadding: messageInputContainerPadding,
              containerDecoration: messageInputContainerDecoration,
              keyboardType: messageInputKeyboardType,
              maxLines: messageInputMaxLines,
              minLines: messageInputMinLines,
              textInputAction: messageInputTextInputAction,
              textCapitalization: messageInputTextCapitalization,
            ),
          ],
        ),
      ),
    );
  }

  AppBar buildAppBar(BuildContext context) {
    return AppBar(
      title: ValueListenableBuilder<ZIMKitConversation>(
        valueListenable: ZIMKit().getConversation(
          conversationID,
          conversationType,
        ),
        builder: (context, conversation, child) {
          const avatarNameFontSize = 16.0;
          return Row(
            children: [
              ClipRRect(
                borderRadius: const BorderRadius.all(Radius.circular(40)),
                child: conversation.icon,
              ),
              child!,
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(
                    conversation.name,
                    style: const TextStyle(
                      fontSize: avatarNameFontSize,
                    ),
                    overflow: TextOverflow.clip,
                  ),
                  // Text(conversation.id,
                  //     style: const TextStyle(fontSize: 12),
                  //     overflow: TextOverflow.clip)
                ],
              )
            ],
          );
        },
        child: const SizedBox(width: 20 * 0.75),
      ),
      actions: appBarActions,
    );
  }
}
